
.. _classic_examples_acoustics_1d_example1:

Acoustics 1D Example 1
------------------------------------------

1D acoustics in a constant medium.

The density and bulk modulus of the medium are specified in setrun.py,
along with the width parameter of the Gaussian pressure pulse used for
the initial condition.

Boundary conditions are outflow at both boundaries.

After running this code and creating plots via "make .plots", you
should be able to view the plots in _plots/_PlotIndex.html.

